from distutils.core import setup

setup(
    name = 'pm-nester',
    version = '1.1.0',
    py_modules = ['pm-nester'],
    author = 'pmodali',
    author_email = 'prasad.modali@yahoo.com',
    url = '',
    description = 'Simple printer of nested lists',
    )
